@@ -29,22 +29,18 @@ class TestLogs(unittest.TestCase):
         n_log_messages = 60
         g = LogsightLogs(self.u.token)
         p = generate_logs(n=n_log_messages)
-        r1 = g.send(self.app_id, p, tag='v1.1.3')
+        r1 = g.send(p, tags={"main": 'v1.1.3'}, app_id=self.app_id)
+        print(r1)
         self.assertEqual(r1['logsCount'], n_log_messages)
-        self.assertEqual(r1['source'], 'REST_BATCH')
 
-        r = g.flush(r1['receiptId'])
-        self.assertTrue('status' in r)
-
-    def test_send_log_file_and_flush(self):
-        file_name = 'hadoop_name_node_v1_1kloc'
-        file_path = os.path.join('./integration/fixtures/', file_name)
-        g = LogsightLogs(self.u.token)
-        r1 = g.upload(self.app_id, file=file_path, tag='v1.1.3')
-        self.assertEqual(r1['source'], 'FILE')
-
-        r = g.flush(r1['receiptId'])
-        self.assertTrue('status' in r)
+    # def test_send_log_file_and_flush(self):
+    #     file_name = 'hadoop_name_node_v1_1kloc'
+    #     file_path = os.path.join('./integration/fixtures/', file_name)
+    #     g = LogsightLogs(self.u.token)
+    #     r1 = g.upload(self.app_id, file=file_path, tag='v1.1.3')
+    #
+    #     r = g.flush(r1['receiptId'])
+    #     self.assertTrue('status' in r)
 
 
 if __name__ == '__main__':
